@@ -5,12 +5,16 @@
   fn <- paste(dn, i.file, sep = "")
   ### Load "libzmq.dll".
   test <- try(dyn.load(fn, local = FALSE), silent = TRUE)
-  if(class(test) == "try-error"){
+  if(inherits(test, "try-error")){
     stop(paste("Could not load ", fn, sep = ""))
   }
 
   ### Load "pbdZMQ.dll".
   library.dynam("pbdZMQ", pkgname, libname)
+
+  ### Preload to global environment.
+  invisible(eval(parse(text = "pbdZMQ:::.zmqopt_init()")))
+
   invisible()
 } # End of .onLoad().
 
